@@ -1,19 +1,23 @@
 from .schema import \
     Schema
 
-from .context import ServiceContextMiddleware
+from .middleware import ServiceMeshMiddleware
 
-from .manager import \
+from .mesh import \
     ServiceManager, \
     ServiceConnection, ServiceConnectionState
 
 from .wsgi import WSGIApp
 
+from graphql_api import field, type
+
 __all__ = [
     'Schema',
-    'ServiceContextMiddleware',
+    'ServiceMeshMiddleware',
     'ServiceManager',
     'ServiceConnection',
     'ServiceConnectionState',
-    'WSGIApp'
+    'WSGIApp',
+    'field',
+    'type'
 ]
