@@ -2,7 +2,9 @@ import inspect
 import logging
 import os
 
-from typing import TypeVar, Optional, Type, Dict
+from typing import TypeVar, Optional, Type, Dict, Callable
+
+from werkzeug.wrappers import Request, Response
 
 from graphql import print_schema, GraphQLSchema
 from graphql_api.utils import to_snake_case
@@ -16,8 +18,7 @@ from graphql_api.remote import GraphQLRemoteExecutor, GraphQLRemoteObject
 
 from graphql_http_server import GraphQLHTTPServer
 
-from graphql_service_framework.context import ServiceContextMiddleware
-from graphql_service_framework.manager import ServiceManager
+from graphql_service_framework.middleware import add_mesh_middleware
 from graphql_service_framework.wsgi import WSGIApp
 
 TClient = TypeVar("TClient", bound='Schema')
@@ -58,28 +59,24 @@ class APIVersion(type):
         super().__init__(name, bases, namespace)
 
 
-class ConfigRootType:
-    """
-    For subclasses of ConfigRootType the "create_app" config dict
-    will be available from the config property
-    """
-
-    def __init__(self, config: Dict = None):
-        self.config = config
-
-
 class Schema(GraphQLRootTypeDelegate, metaclass=APIVersion):
     api_version: str = None
     validate_schema: bool = True
     criticality: Optional[CriticalityLevel] = CriticalityLevel.NonBreaking
     ignore_description_changes: bool = True
 
-    def __new__(cls, url: str = None, *args, **kwargs):
+    def __init__(self, config: Dict = None, url: str = None):
+        if not config:
+            config = {}
+        self.config = config
+        self.url = url
+
+    def __new__(cls, config: Dict = None, url: str = None, *args, **kwargs):
         schema_class = cls.get_schema_class()
         if cls == schema_class:
             return cls.client(url=url)
 
-        return super(Schema, cls).__new__(cls, *args, **kwargs)
+        return super(Schema, cls).__new__(cls)
 
     @classmethod
     def get_schema_class(cls):
@@ -116,55 +113,6 @@ class Schema(GraphQLRootTypeDelegate, metaclass=APIVersion):
 
         return schema
 
-    @classmethod
-    def create_app(cls, config: Dict = None) -> WSGIApp:
-        if not config:
-            config = {}
-        service_name = config.get("service_name", to_snake_case(cls.__name__))
-        graphiql_default = config.get("graphiql_default", "")
-        relative_path = config.get("http_relative_path", "")
-        health_path = config.get("http_health_path", f"{relative_path}/health")
-        api_version = config.get("api_version", cls.api_version)
-        service_management_path = config.get(
-            "http_service_management_path", f"{relative_path}/service")
-
-        if not graphiql_default:
-            try:
-                dirname = os.path.dirname(inspect.getfile(cls))
-                graphiql_default = open(
-                    os.path.join(dirname, '../graphiql_default.graphql'),
-                    mode='r'
-                ).read()
-            except Exception:
-                try:
-                    dirname = os.path.dirname(inspect.getfile(cls))
-                    graphiql_default = open(
-                        os.path.join(dirname, '../.graphql'),
-                        mode='r'
-                    ).read()
-                except Exception:
-                    pass
-
-        if issubclass(cls, ConfigRootType) and config:
-            cls: Type[ConfigRootType]
-            root_value = cls(config=config)
-        else:
-            root_value = None
-
-        graphql_http_server = GraphQLHTTPServer.from_api(
-            api=GraphQLAPI(root=cls),
-            root_value=root_value,
-            graphiql_default_query=graphiql_default,
-            health_path=health_path
-        )
-
-        app = ServiceContextMiddleware(
-            graphql_http_server.app(),
-            ServiceManager(name=service_name, api_version=api_version),
-            service_management_path=service_management_path
-        )
-        return app
-
     @classmethod
     def client(cls: TClient, url: str = None) -> TClient:
         if not url:
@@ -184,6 +132,62 @@ class Schema(GraphQLRootTypeDelegate, metaclass=APIVersion):
     def graphql_schema(cls) -> GraphQLSchema:
         return GraphQLAPI(root=cls).graphql_schema()[0]
 
+    def create_app(
+            self,
+            config: Dict = None,
+            main: Callable[[Request], Response] = None
+    ) -> WSGIApp:
+        if not config:
+            config = {}
+
+        config = {**self.config, **config}
+
+        graphiql_default = config.get("graphiql_default", "")
+        relative_path = config.get("http_relative_path", "")
+
+        if not config.get("service_name"):
+            config["service_name"] = to_snake_case(self.__class__.__name__)
+
+        if not config.get("api_version"):
+            config["api_version"] = self.__class__.api_version
+
+        if not config.get("http_health_path"):
+            config["http_health_path"] = f"{relative_path}/health"
+
+        health_path = config.get("http_health_path")
+
+        if not graphiql_default:
+            # noinspection PyBroadException
+            try:
+                dirname = os.path.dirname(inspect.getfile(self.__class__))
+                graphiql_default = open(
+                    os.path.join(dirname, '../graphiql_default.graphql'),
+                    mode='r'
+                ).read()
+            except Exception:
+                # noinspection PyBroadException
+                try:
+                    dirname = os.path.dirname(inspect.getfile(self.__class__))
+                    graphiql_default = open(
+                        os.path.join(dirname, '../.graphql'),
+                        mode='r'
+                    ).read()
+                except Exception:
+                    pass
+
+        graphql_http_server = GraphQLHTTPServer.from_api(
+            api=GraphQLAPI(root=self.__class__),
+            root_value=self,
+            graphiql_default_query=graphiql_default,
+            health_path=health_path
+        )
+
+        app = graphql_http_server.app(main=main)
+
+        app = add_mesh_middleware(app, config)
+
+        return app
+
 
 def validate(
         graphql_schema: GraphQLSchema,
