@@ -1,3 +1,4 @@
+import dataclasses
 import difflib
 import importlib
 import inspect
@@ -9,10 +10,19 @@ import sys
 
 from typing import Optional
 
-from graphql_service_framework.schema import Schema
+
+def dataclass_from_dict(klass, d):
+    # noinspection PyBroadException
+    try:
+        f_types = {f.name: f.type for f in dataclasses.fields(klass)}
+        return klass(**{f: dataclass_from_dict(f_types[f], d[f]) for f in d})
+    except Exception:
+        return d
 
 
 def set_api_version(code, new_version):
+    from graphql_service_framework.schema import Schema
+
     schema_class_name = Schema.__name__
     if f"{schema_class_name}, api_version=" not in code.lower():
         old = f"{schema_class_name}):\n"
@@ -60,6 +70,7 @@ def find_schema(modules):
 
     for module in modules:
         for name, obj in module.__dict__.items():
+            from graphql_service_framework import Schema
             if inspect.isclass(obj) \
                     and issubclass(obj, Schema) \
                     and obj != Schema:
